@@ -42,8 +42,8 @@ lpb <- function(x, nsim=100)
 # Author: Fotios Petropoulos
 
 MBB <- function(x, window_size) {
-  
-  bx = array(0, (floor(length(x)/window_size)+2)*window_size)
+
+  bx <- array(0, (floor(length(x)/window_size)+2)*window_size)
   for (i in 1:(floor(length(x)/window_size)+2)){
     c <- sample(1:(length(x)-window_size+1),1)
     bx[((i-1)*window_size+1):(i*window_size)] <- x[c:(c+window_size-1)]
@@ -56,14 +56,14 @@ MBB <- function(x, window_size) {
 
 
 #' Box-Cox and Loess-based decomposition bootstrap.
-#' 
+#'
 #' Generates bootstrapped versions of a time series using the Box-Cox and
 #' Loess-based decomposition bootstrap.
-#' 
+#'
 #' The procedure is described in Bergmeir et al. Box-Cox decomposition is
 #' applied, together with STL or Loess (for non-seasonal time series), and the
 #' remainder is bootstrapped using a moving block bootstrap.
-#' 
+#'
 #' @param x Original time series.
 #' @param num Number of bootstrapped versions to generate.
 #' @param block_size Block size for the moving block bootstrap.
@@ -77,20 +77,25 @@ MBB <- function(x, window_size) {
 #' @keywords ts
 #' @examples
 #' bootstrapped_series <- bld.mbb.bootstrap(WWWusage, 100)
-#' 
+#'
 #' @export
-bld.mbb.bootstrap <- function(x, num, block_size = if(frequency(x)>1) 2*frequency(x) else 8 ) {
+bld.mbb.bootstrap <- function(x, num, block_size=NULL)
+{
 
   freq <- frequency(x)
-  
+  if(is.null(block_size))
+  {
+    block_size <- ifelse(freq > 1, 2*freq, min(8, floor(length(x)/ 2)))
+  }
+
   xs <- list()
   xs[[1]] <- x # the first series is the original one
-  
+
   if (num>1){
     # Box-Cox transformation
     lambda <- BoxCox.lambda(x, lower=0, upper=1)
     x.bc <- BoxCox(x, lambda)
-    
+
     if (freq>1){
       # STL decomposition
       x.stl <- stl(ts(x.bc, frequency=freq), "per")$time.series
@@ -99,18 +104,18 @@ bld.mbb.bootstrap <- function(x, num, block_size = if(frequency(x)>1) 2*frequenc
       remainder <- x.stl[,3]
     } else {
       # Loess
-      trend <- 1:length(x) 
+      trend <- 1:length(x)
       suppressWarnings(x.loess <- loess(x.bc ~ trend, span=6/length(x), degree=1))
       seasonal <- rep(0, length(x))
       trend <- x.loess$fitted
       remainder <- x.loess$residuals
     }
-    
+
     # Bootstrap some series, using MBB
-    for (i in 2:num){      
+    for (i in 2:num){
       xs[[i]] <- InvBoxCox(trend + seasonal + MBB(remainder, block_size), lambda)
     }
   }
-  
+
   xs
 }
