@@ -1,15 +1,15 @@
 ####################################################################
 ## Double Seasonal Holt Winters method as per Taylor (2003)
-## Periods must be nested. 
+## Periods must be nested.
 ## y can be an msts object, or periods can be passed explicitly.
 ####################################################################
 
 
 
 #' Double-Seasonal Holt-Winters Forecasting
-#' 
+#'
 #' Returns forecasts using Taylor's (2003) Double-Seasonal Holt-Winters method.
-#' 
+#'
 #' Taylor's (2003) double-seasonal Holt-Winters method uses additive trend and
 #' multiplicative seasonality, where there are two seasonal components which
 #' are multiplied together. For example, with a series of half-hourly data, one
@@ -17,7 +17,7 @@
 #' the weekly period. The smoothing parameter notation used here is different
 #' from that in Taylor (2003); instead it matches that used in Hyndman et al
 #' (2008) and that used for the \code{\link{ets}} function.
-#' 
+#'
 #' @param y Either an \code{\link{msts}} object with two seasonal periods or a
 #' numeric vector.
 #' @param period1 Period of the shorter seasonal period. Only used if \code{y}
@@ -47,45 +47,45 @@
 #' @param model If it's specified, an existing model is applied to a new data
 #' set.
 #' @return An object of class "\code{forecast}" which is a list that includes the
-#' following elements: 
-#'   \item{model}{A list containing information about the fitted model} 
-#'   \item{method}{The name of the forecasting method as a character string} 
+#' following elements:
+#'   \item{model}{A list containing information about the fitted model}
+#'   \item{method}{The name of the forecasting method as a character string}
 #'   \item{mean}{Point forecasts as a time series}
-#'   \item{x}{The original time series.} 
-#'   \item{residuals}{Residuals from the fitted model. That is x minus fitted values.} 
+#'   \item{x}{The original time series.}
+#'   \item{residuals}{Residuals from the fitted model. That is x minus fitted values.}
 #'   \item{fitted}{Fitted values (one-step forecasts)}
-#' 
+#'
 #' The function \code{summary} is used to obtain and print a summary of the
 #' results, while the function \code{plot} produces a plot of the forecasts.
-#' 
+#'
 #' The generic accessor functions \code{fitted.values} and \code{residuals}
 #' extract useful features of the value returned by \code{dshw}.
-#' 
+#'
 #' @author Rob J Hyndman
 #' @seealso \code{\link[stats]{HoltWinters}}, \code{\link{ets}}.
 #' @references Taylor, J.W. (2003) Short-term electricity demand forecasting
 #' using double seasonal exponential smoothing. \emph{Journal of the
-#' Operational Reseach Society}, \bold{54}, 799-805.
-#' 
+#' Operational Research Society}, \bold{54}, 799-805.
+#'
 #' Hyndman, R.J., Koehler, A.B., Ord, J.K., and Snyder, R.D. (2008)
 #' \emph{Forecasting with exponential smoothing: the state space approach},
 #' Springer-Verlag. \url{http://www.exponentialsmoothing.net}.
 #' @keywords ts
 #' @examples
-#' 
+#'
 #' \dontrun{
 #' fcast <- dshw(taylor)
 #' plot(fcast)
-#' 
+#'
 #' t <- seq(0,5,by=1/20)
 #' x <- exp(sin(2*pi*t) + cos(2*pi*t*4) + rnorm(length(t),0,.1))
 #' fit <- dshw(x,20,5)
 #' plot(fit)
 #' }
-#' 
+#'
 #' @export
-dshw <- function(y, period1=NULL, period2=NULL, h=2*max(period1,period2), 
-  alpha=NULL, beta=NULL, gamma=NULL, omega=NULL, phi=NULL, lambda=NULL, biasadj=FALSE, 
+dshw <- function(y, period1=NULL, period2=NULL, h=2*max(period1,period2),
+  alpha=NULL, beta=NULL, gamma=NULL, omega=NULL, phi=NULL, lambda=NULL, biasadj=FALSE,
   armethod=TRUE, model = NULL)
 {
   if(min(y,na.rm=TRUE) <= 0)
@@ -109,12 +109,15 @@ dshw <- function(y, period1=NULL, period2=NULL, h=2*max(period1,period2),
   }
   if(any(class(y) != "msts"))
     y <- msts(y, c(period1, period2))
-	
+
+  if(length(y) < 2*max(period2))
+    stop("Insufficient data to estimate model")
+
   if(!armethod)
     phi <- 0
-  
+
   if(period1 < 1 | period1 == period2)
-    stop("Inappropriate periods") 
+    stop("Inappropriate periods")
   ratio <- period2/period1
   if(ratio-trunc(ratio) > 1e-10)
     stop("Seasonal periods are not nested")
@@ -189,7 +192,7 @@ dshw <- function(y, period1=NULL, period2=NULL, h=2*max(period1,period2),
 	# Forecasts
   fcast <- (s + (1:h)*t) * rep(I[n+(1:period1)],h/period1 + 1)[1:h] * rep(w[n+(1:period2)],h/period2 + 1)[1:h]
   fcast <- ts(fcast,frequency=frequency(y),start=tsp(y)[2]+1/tsp(y)[3])
-  
+
   # Calculate MSE and MAPE
   yhat <- ts(yhat)
   tsp(yhat) <- tsp(y)
@@ -204,7 +207,7 @@ dshw <- function(y, period1=NULL, period2=NULL, h=2*max(period1,period2),
 	}
 	mse <- mean(e^2)
 	mape <- mean(abs(e)/y)*100
-  
+
 
   end.y <- end(y)
   if(end.y[2] == frequency(y)) {
@@ -213,9 +216,9 @@ dshw <- function(y, period1=NULL, period2=NULL, h=2*max(period1,period2),
   } else {
 	  end.y[2] <- end.y[2]+1
   }
-  
+
   fcast <- msts(fcast, c(period1, period2))
-  
+
   if(!is.null(lambda))
   {
     y <- origy
@@ -270,6 +273,6 @@ seasindex <- function(y,p)
   {
     average[(p-1)/2 + 1:p] <- shorty[(p-1)/2 + 1:p]/simplema[1:p]
     si <- average[c(p+(1:((p-1)/2)),(1+(p-1)/2):p)]
-  } 
+  }
   return(si)
 }
