@@ -71,11 +71,12 @@ fitPreviousTBATSModel <- function (y, model, biasadj=FALSE) {
   }
 
   model.for.output <- model
-  model.for.output$variance = variance
-  model.for.output$fitted.values = c(fitted.values)
-  model.for.output$errors=c(e)
-  model.for.output$x=fitted.values.and.errors$x
-  model.for.output$y=y
+  model.for.output$variance <- variance
+  model.for.output$fitted.values <- ts(c(fitted.values))
+  model.for.output$errors <- ts(c(e))
+  tsp(model.for.output$fitted.values) <- tsp(model.for.output$errors) <- tsp(y)
+  model.for.output$x <- fitted.values.and.errors$x
+  model.for.output$y <- y
   return(model.for.output)
 
 }
@@ -114,7 +115,7 @@ fitSpecificTBATS <- function(y, use.box.cox, use.beta, use.damping, seasonal.per
       beta.v <- NULL
       b <- NULL
       small.phi <- NULL
-      use.damping=FALSE
+      use.damping <- FALSE
     }
     if(!is.null(seasonal.periods)) {
       gamma.one.v <- rep(0, length(k.vector))
@@ -236,7 +237,7 @@ fitSpecificTBATS <- function(y, use.box.cox, use.beta, use.damping, seasonal.per
   }
   w.tilda.transpose <- matrix(0, nrow=length(y), ncol=ncol(w$w.transpose))
   w.tilda.transpose[1,] <- w$w.transpose
-  w.tilda.transpose=.Call("calcWTilda", wTildaTransposes=w.tilda.transpose, Ds=D, PACKAGE = "forecast")
+  w.tilda.transpose <- .Call("calcWTilda", wTildaTransposes=w.tilda.transpose, Ds=D, PACKAGE = "forecast")
   #Remove the AR() and MA() bits if they exist
   if((p != 0) | (q != 0)) {
     end.cut <- ncol(w.tilda.transpose)
@@ -361,7 +362,11 @@ fitSpecificTBATS <- function(y, use.box.cox, use.beta, use.damping, seasonal.per
 
 
   #Make a list object
-  model.for.output <- list(lambda=lambda, alpha=alpha, beta=beta.v, damping.parameter=small.phi, gamma.one.values=gamma.one.v, gamma.two.values=gamma.two.v, ar.coefficients=ar.coefs, ma.coefficients=ma.coefs, likelihood=likelihood, optim.return.code=optim.like$convergence, variance=variance, AIC=aic, parameters=list(vect=optim.like$par, control=param.vector$control), seed.states=x.nought, fitted.values=c(fitted.values), errors=c(e), x=fitted.values.and.errors$x, seasonal.periods=seasonal.periods, k.vector=k.vector, y=y, p=p, q=q)
+  fits <- ts(c(fitted.values))
+  e <- ts(c(e))
+  tsp(fits) <- tsp(e) <- tsp(y)
+  model.for.output <- list(lambda=lambda, alpha=alpha, beta=beta.v, damping.parameter=small.phi, gamma.one.values=gamma.one.v, gamma.two.values=gamma.two.v, ar.coefficients=ar.coefs, ma.coefficients=ma.coefs, likelihood=likelihood, optim.return.code=optim.like$convergence, variance=variance, AIC=aic, parameters=list(vect=optim.like$par, control=param.vector$control), seed.states=x.nought, 
+    fitted.values=fits, errors=e, x=fitted.values.and.errors$x, seasonal.periods=seasonal.periods, k.vector=k.vector, y=y, p=p, q=q)
   class(model.for.output) <- c("tbats","bats")
   return(model.for.output)
 }
