@@ -1,3 +1,57 @@
+#' Forecasting using BATS and TBATS models
+#' 
+#' Forecasts \code{h} steps ahead with a BATS model. Prediction intervals are
+#' also produced.
+#' 
+#' @param object An object of class "\code{bats}". Usually the result of a call
+#' to \code{\link{bats}}.
+#' @param h Number of periods for forecasting. Default value is twice the
+#' largest seasonal period (for seasonal data) or ten (for non-seasonal data).
+#' @param level Confidence level for prediction intervals.
+#' @param fan If TRUE, level is set to \code{seq(51,99,by=3)}. This is suitable
+#' for fan plots.
+#' @param biasadj Use adjusted back-transformed mean for Box-Cox
+#' transformations. If TRUE, point forecasts and fitted values are mean
+#' forecast. Otherwise, these points can be considered the median of the
+#' forecast densities.
+#' @param ... Other arguments, currently ignored.
+#' @return An object of class "\code{forecast}".
+#' 
+#' The function \code{summary} is used to obtain and print a summary of the
+#' results, while the function \code{plot} produces a plot of the forecasts and
+#' prediction intervals.
+#' 
+#' The generic accessor functions \code{fitted.values} and \code{residuals}
+#' extract useful features of the value returned by \code{forecast.bats}.
+#' 
+#' An object of class \code{"forecast"} is a list containing at least the
+#' following elements: \item{model}{A copy of the \code{bats} object}
+#' \item{method}{The name of the forecasting method as a character string}
+#' \item{mean}{Point forecasts as a time series} \item{lower}{Lower limits for
+#' prediction intervals} \item{upper}{Upper limits for prediction intervals}
+#' \item{level}{The confidence values associated with the prediction intervals}
+#' \item{x}{The original time series (either \code{object} itself or the time
+#' series used to create the model stored as \code{object}).}
+#' \item{residuals}{Residuals from the fitted model.} \item{fitted}{Fitted
+#' values (one-step forecasts)}
+#' @author Slava Razbash and Rob J Hyndman
+#' @seealso \code{\link{bats}}, \code{\link{tbats}},\code{\link{forecast.ets}}.
+#' @references De Livera, A.M., Hyndman, R.J., & Snyder, R. D. (2011),
+#' Forecasting time series with complex seasonal patterns using exponential
+#' smoothing, \emph{Journal of the American Statistical Association},
+#' \bold{106}(496), 1513-1527.
+#' @keywords ts
+#' @examples
+#' 
+#' \dontrun{
+#' fit <- bats(USAccDeaths)
+#' plot(forecast(fit))
+#' 
+#' taylor.fit <- bats(taylor)
+#' plot(forecast(taylor.fit))
+#' }
+#' 
+#' @export
 forecast.bats <- function(object, h, level=c(80,95), fan=FALSE, biasadj=NULL, ...)
 {
   #Set up the variables
@@ -93,10 +147,10 @@ forecast.bats <- function(object, h, level=c(80,95), fan=FALSE, biasadj=NULL, ..
   upper.bounds <- msts(upper.bounds, seasonal.periods=(if(!is.null(object$seasonal.periods)) { object$seasonal.periods} else { ts.frequency}), ts.frequency=ts.frequency, start=fcast.start.time)
   lower.bounds <- msts(lower.bounds, seasonal.periods=(if(!is.null(object$seasonal.periods)) { object$seasonal.periods} else { ts.frequency}), ts.frequency=ts.frequency, start=fcast.start.time)
   colnames(upper.bounds) <- colnames(lower.bounds) <- paste0(level, "%")
-  
+
   forecast.object <- list(model=object, mean=y.forecast, level=level, x=x, series=object$series,
 	                        upper=upper.bounds, lower=lower.bounds, fitted=fitted.values,
-	                        method=makeText(object), residuals=object$errors)
+	                        method=as.character(object), residuals=object$errors)
 	if(is.null(object$series)){
 	  forecast.object$series <- deparse(object$call$y)
 	}
@@ -105,37 +159,38 @@ forecast.bats <- function(object, h, level=c(80,95), fan=FALSE, biasadj=NULL, ..
 }
 
 
-makeText <- function(object) {
+#' @export
+as.character.bats <- function(x, ...) {
 	name <- "BATS("
-	if(!is.null(object$lambda)) {
-		name <- paste(name, round(object$lambda, digits=3), sep="")
+	if(!is.null(x$lambda)) {
+		name <- paste(name, round(x$lambda, digits=3), sep="")
 	} else {
 		name <- paste(name, "1", sep="")
 	}
 	name <- paste(name, ", {", sep="")
-	if(!is.null(object$ar.coefficients)) {
-		name <- paste(name, length(object$ar.coefficients), sep="")
+	if(!is.null(x$ar.coefficients)) {
+		name <- paste(name, length(x$ar.coefficients), sep="")
 	} else {
 		name <- paste(name, "0", sep="")
 	}
 	name <- paste(name, ",", sep="")
-	if(!is.null(object$ma.coefficients)) {
-		name <- paste(name, length(object$ma.coefficients), sep="")
+	if(!is.null(x$ma.coefficients)) {
+		name <- paste(name, length(x$ma.coefficients), sep="")
 	} else {
 		name <- paste(name, "0", sep="")
 	}
 	name <- paste(name, "}, ", sep="")
-	if(!is.null(object$damping.parameter)) {
-		name <- paste(name, round(object$damping.parameter, digits=3), sep="")
+	if(!is.null(x$damping.parameter)) {
+		name <- paste(name, round(x$damping.parameter, digits=3), sep="")
 	} else {
 		name <- paste(name, "-", sep="")
 	}
 	name <- paste(name, ", ", sep="")
-	if(!is.null(object$seasonal.periods)) {
+	if(!is.null(x$seasonal.periods)) {
     name <- paste(name,"{",sep="")
-		for(i in object$seasonal.periods) {
+		for(i in x$seasonal.periods) {
 			name <- paste(name, i, sep="")
-			if(i != object$seasonal.periods[length(object$seasonal.periods)]) {
+			if(i != x$seasonal.periods[length(x$seasonal.periods)]) {
 				name <- paste(name, ",", sep="")
 			} else {
 				name <- paste(name, "})", sep="")
