@@ -19,14 +19,14 @@ if(require(testthat))
 	})
 	test_that("tests for accuracy",{
 	# Test arima
-	fitarima <- auto.arima(USAccDeaths)
+	fitarima <- Arima(USAccDeaths, order = c(0,1,1), seasonal = c(0,1,1))
 	accuracyarima <- accuracy(fitarima)[1, "RMSE"]
-	accuracyarimasim <- accuracy(auto.arima(simulate(fitarima, seed = 123)))[1, "RMSE"]
+	accuracyarimasim <- accuracy(Arima(simulate(fitarima, seed = 123), order = c(0,1,0), seasonal = c(0,0,1)))[1, "RMSE"]
 	expect_lt(accuracyarima, accuracyarimasim)
 	# Test ets
-	fitets <- ets(AirPassengers)
+	fitets <- ets(AirPassengers, model = "MAM", damped = TRUE)
 	accuracyets <- accuracy(fitets)[1, "RMSE"]
-	accuracyetssim <- accuracy(ets(simulate(fitets, seed = 123)))[1, "RMSE"]
+	accuracyetssim <- accuracy(ets(simulate(fitets, seed = 123), model="MAM", damped = TRUE))[1, "RMSE"]
 	expect_lt(accuracyets, accuracyetssim)
 	# Test lm
 	month <- factor(rep(1:12, 14))
