@@ -1,11 +1,11 @@
 # A unit test for na.interp() and tsclean()
-if(require(fpp) & require(testthat))
+if(require(testthat))
 {
 test_that("tests for na.interp", {
   # Test nonseasonal interpolation
   expect_true(all(na.interp(c(1, 2, 3, NA, 5, 6, 7)) == 1:7))
   # Test for identical on series without NAs
-  expect_true(all(na.interp(a10) == a10))
+  expect_true(all(na.interp(wineind) == wineind))
   # Test seasonal interpolation
   testseries <- ts(rep(1:7, 5), f = 7)
   testseries[c(1, 3, 11, 17)] <- NA
